# omeku.py
A Python module that uses Omeku API

## Requirements
- Python 3.6 and up - https://www.python.org/downloads/

# Install
```
pip install omeku.py
```

# Usage example
```py
import omeku
print(omeku.img('neko'))

>>> 'https://omeku.glitch.me/neko/neko_13.png'
```

